
/*==============================================================================
HAITI 2021 - 2022 HIGH FREQUENCY SURVEY ANALYSIS
===============================================================================*/

*******************************
********     WAVE 2    ********
*******************************

clear all
set more off

global path "C:/WBG/rep-checks/RR_HTI_2024_83"

global rawdata "${path}/_data/raw"

global data "${path}/_data/constructed"

global out "${path}/_out"

sysdir set PLUS "${path}/_do/ado"

use "$rawdata\509_ph2w2_casos_library.dta", clear 

*Generation final data base.
*Adjusting the region variable

gen subnatID2 = v03_05
lab def subnatID2 50901  "Ouest" 50902  "Sud-Est" 50903  "Nord" 50904  "Nord-Est" 50905  "Artibonite" 50906  ///
"Centre" 50907  "Sud" 50908  "Grande'Anse" 50909  "Nord-Ouest" 50910  "Nippes"
lab val subnatID2 subnatID2
tab subnatID2, gen(subnat)


recode v03_05 (50901 = 1) (50902 50907 50908 50910 =2) (50903 50904 50909 = 3) (50905 50906 = 4), gen(haiti_regions)

lab def haiti_regions 1  "Ouest" 2 "Southern" 3 "Northern" 4  "Central" 
lab val haiti_regions haiti_regions
tab haiti_regions, gen(region_)


*merge children data sets.
merge 1:m folio using "$rawdata/509_ph2w2_ninos_0_5_library.dta", force
merge 1:m folio using "$rawdata/509_ph2w2_ninos_6_17_library.dta", gen (_merge2) force

save "$data\HAITI_HFS21_W2.dta", replace

********************************************************************************
use "$data\HAITI_HFS21_W2.dta", clear 

cd "$out"
*****************************************************
*Figure 1
*****************************************************

	******************
	*** - What types of natural hazards do you think threaten your home? - Aggregate
	******************

	foreach i in `c(alpha)' {
	if "`i'"<="m" {

	replace v15_03`i'=0 if v15_03`i'!=1

	}
	}

	br v15_03*

	egen hazard=rowtotal(v15_03a v15_03b v15_03c v15_03d v15_03e v15_03f v15_03g v15_03h v15_03i v15_03j v15_03k v15_03l v15_03m)

	br v15_03* hazard


	tab hazard
	recode hazard (0=0 "0 hazards") (1/2= 1 "1-2 hazards") (3/12=2 "3 or more hazards"), gen(hazard_exp)
	tab hazard_exp [iw=w_hh_ph2w2]

	*output to excel 
	tabout v03_08a hazard_exp [iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) replace
	
*****************************************************
*Figure 2
*****************************************************

	
	******************
	*** - What types of natural hazards do you think threaten your home? - Disaggregated
	******************

	foreach i in `c(alpha)' {
	if "`i'"<="m" {

	tab v03_08a v15_03`i', m row nofreq

	*output to excel 
	tabout v03_08a v15_03`i' [iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
		
	}
	}
	

*****************************************************
*Regressions - Figure 3
*****************************************************


* Sex household head

tab v03_01
gen household_head_fem=.
replace household_head_fem=1 if (v03_04==2 & v03_01==1) | v03_10d==2
replace household_head_fem=0 if (v03_04==1 & v03_01==1) | v03_10d==1
tab household_head_fem 
label def household_head_fem 1 "Female" 0 "Male"
label val household_head_fem household_head_fem


*household head age
tab v03_03
gen age_range=.
replace age_range=v03_03 if v03_01==1
replace age_range=v03_10c if v03_01!=1
tab age_range
replace age_range=. if age_range==99
recode age_range (18/29=1 "18 to 29") (30/49=2 "30 to 49") (50/90=3 "50+"), gen(age_head)
tab age_head


*children 0-17 at home
tab v07_16, m
recode v07_16 (0=0 "no children") (1/2=1 "1-2 children") (3/10=3 "3+ children"), gen(children)
tab children, m


*education of head of household
recode v03_09a (50901/50908 = 1) (50909/50915 = 2) (50916 = 3) (50999 = .), gen(education)
lab def education 1 "No Educ./Primary" 2 "Secondary" 3 "Tertiary or more"
lab val education education
replace education=0 if v03_01!=1
replace education=1 if v03_10a>=50901 & v03_10a<=50908
replace education=2 if v03_10a>=50909 & v03_10a<=50915
replace education=3 if v03_10a==50916
replace education=. if v03_10a==50999
tab education


*location
tab haiti_regions
recode haiti_regions (1=1 "Ouest") (2=2 "Southern") (3=3 "Northern") (4=4 "Central"), gen (region)

*area
tab v03_08a
recode v03_08a (1=1 "Urban") (2=2 "Rural"), gen(area)

*regression *Affected by Earthquake

tab v15_01, nol
replace v15_01=0 if v15_01==2 

probit v15_01 i.household_head_fem ib(last).age_head i.children i.education i.region i.area [iw=w_hh_ph2w2], vce(robust)
estimates store earthquake

* Compute margins

estimates restore earthquake
margins, dydx(*) vce(unconditional) post
estimates store marg_earthquake

coefplot marg_earthquake, drop(_cons) ///
	headings(1.household_head_fem = `""{bf: Head of household: sex}" "{it:(Ref.: male)}"' ///
			 1.age_head = `""{bf: Age group}" "{it:(Ref.: 50+ years)}"'  ///
			 1.children = `""{bf: Number of children (0-17)}" "{it:(Ref.: no children)}"' ///
			 2.education = `""{bf: Educational attainment}" "{it:(Ref.: Primary or less)}"' ///
			 2.region = `""{bf: Region}" "{it:(Ref.: Ouest)}"' 2.area =`""{bf: Area}" "{it:(Ref.: Urban)}"', labsize(small))  xline(0, lcolor(navy) lpattern(dash)) ///
			subtitle("Households affected by the August, 2021 earthquake", size(medsmall) color(black) margin(small) ///
			 box bmargin(small) lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(medsmall) ticks tlength(medium)) ///
			 scheme(sj) ymtick(, labels labsize(medsmall)) 
graph export "$out/graph1_w2.png", replace

*********************************************************************
*First paragraph Section 3 - Figure 4a - Does your community have...
*********************************************************************

	
	gen emergency_plan = 0
	*replace emergency_plan=. if v15_12a==98
	replace emergency_plan = 1 if (v15_12a == 1)
	tab emergency_plan
	tab v03_08a emergency_plan [iw=w_hh_ph2w2], row nofreq
	
	gen committee = 0
	*replace committee=. if v15_12b==98
	replace committee = 1 if (v15_12b == 1)
	tab committee
	tab v03_08a committee [iw=w_hh_ph2w2], row nofreq
	
	gen trained_community = 0
	*replace trained_community=. if v15_12c==98
	replace trained_community = 1 if (v15_12c == 1)
	tab trained_community
	tab v03_08a trained_community [iw=w_hh_ph2w2], row nofreq
	
	gen evacuation_routes = 0
	*replace evacuation_routes=. if v15_12d==98
	replace evacuation_routes = 1 if (v15_12d == 1)
	tab evacuation_routes
	tab v03_08a evacuation_routes [iw=w_hh_ph2w2], row nofreq
	
	gen shelter = 0
	*replace shelter=. if v15_12e==98
	replace shelter = 1 if (v15_12e == 1)
	tab shelter
	tab v03_08a shelter [iw=w_hh_ph2w2], row nofreq
	

	**by household head
tab household_head_fem [iw=w_hh_ph2w2]


tab household_head_fem emergency_plan 			[iw=w_hh_ph2w2], row nofreq
tab household_head_fem committee 				[iw=w_hh_ph2w2], row nofreq
tab household_head_fem trained_community 		[iw=w_hh_ph2w2], row nofreq
tab household_head_fem evacuation_routes 		[iw=w_hh_ph2w2], row nofreq
tab household_head_fem shelter 					[iw=w_hh_ph2w2], row nofreq

tabout household_head_fem emergency_plan 		[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout household_head_fem committee 			[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout household_head_fem trained_community 	[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout household_head_fem evacuation_routes 	[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout household_head_fem shelter 				[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append 

**by area
tabout v03_08a emergency_plan 		[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout v03_08a committee 			[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout v03_08a trained_community 	[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout v03_08a evacuation_routes 	[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout v03_08a shelter 				[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append 

*********************************************************************************************************************************
**** Not in the paper but checking results on significance by sex of head of household head for first paragraph third section
*********************************************************************************************************************************



	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate household_head_fem [aw=w_hh_ph2w2], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.household_head_fem [aw=w_hh_ph2w2], vce(robust)
	
	
	}


	
******************************************************
*Regressions - Figure 10 - Correlates with prepardness
******************************************************


	*Outcome variable - Prepared to deal with a disaster
	
	****************
	*** - Do you feel that your household is very prepared, somewhat prepared, or not prepared to deal with a disaster or emergency at this time?
	****************
	
	tab v15_04, m
	tab v15_04, nol
	
	******************
	*** - Does your household have cable internet and/or WiFi?
	******************	
	
	tab v11_08, m
	tab v11_08, nol
	
	gen internet = 0
	replace internet=. if v11_08==98
	replace internet = 1 if (v11_08 == 1)
	tab internet
	label def internet 1 "Yes" 0 "No"
	label val internet internet
		
	*One will be very or somewhat prepared and zero will be not prepared or don't know
	gen prepared = 0
	replace prepared = 1 if (v15_04 == 1 | v15_04 == 2)
	tab prepared

	*regression *households prepared to deal with a disaster
	probit prepared i.household_head_fem ib(last).age_head i.children i.education i.region i.area i.internet [iw=w_hh_ph2w2], vce(robust)
	estimates store prepared

	* Compute margins

	estimates restore prepared
	margins, dydx(*) vce(unconditional) post
	estimates store marg_prepared

	coefplot marg_prepared, drop(_cons) ///
		headings(1.household_head_fem = `"{bf: Head of household: sex}"' ///
				 1.age_head = `"{bf: Age group}"'  ///
				 1.children = `"{bf: Number of children (0-17)}"' ///
				 2.education = `"{bf: Educational attainment}"' ///
				 1.internet = `"{bf: Internet access}"' ///
				 2.region = `"{bf: Region}"' ///
				 2.area = `"{bf: Area}"', labsize(medium_small))  xline(0, lcolor(navy) lpattern(dash)) ///
				 subtitle("Households prepared to deal with a disaster", size(medium_small) color(black) margin(small) ///
				 box bmargin(small) lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(medium_small) ticks tlength(tiny_small) alternate) ///
				 scheme(sj) ymtick(, labels labsize(medium_small))	
graph export "$out/graph2_w2.png", replace

	*graph save 	"C:\Users\mycar\OneDrive\Escritorio\Gender Assessment Haiti\Deep dives\Aditional_graphs\WVS\graph1", replace	

	
*Figure 8 on shelters by type of natural hazard *******************************************

foreach var of varlist v15_03a v15_03b v15_03c v15_03d v15_03e v15_03f v15_03g v15_03h v15_03i v15_03j v15_03k v15_03l v15_03m { 

tab `var' v15_12e [iw=w_hh_ph2w2], row 

}

	*output to excel 
	tabout v15_03a v15_12e [iw=w_hh_ph2w2] using tables_shelter_w2.xls, c(row) f(1) replace

	foreach i in `c(alpha)' {
	if "`i'"<="l" {

	tab v15_03`i' v15_12e, row nofreq

	*output to excel 
	tabout v15_03`i' v15_12e [iw=w_hh_ph2w2] using tables_shelter_w2.xls, c(row) f(1) append
		
	}
	}
	
	*Urban
		foreach i in `c(alpha)' {
	if "`i'"<="l" {

	tab v15_03`i' v15_12e, row nofreq

	*output to excel 
	tabout v15_03`i' v15_12e [iw=w_hh_ph2w2] if v03_08a==1 using tables_shelter_w2.xls, c(row) f(1) append
		
	}
	}
	
		*rural
		foreach i in `c(alpha)' {
	if "`i'"<="l" {

	tab v15_03`i' v15_12e, row nofreq

	*output to excel 
	tabout v15_03`i' v15_12e [iw=w_hh_ph2w2] if v03_08a==2 using tables_shelter_w2.xls, c(row) f(1) append
		
	}
	}
*########################################################################################################
*							WAVE 1-WAVE 2                                              *
*########################################################################################################


**# Bookmark #2
merge 1:m folio using "$data\HAITI_HFS21_W1_Q.dta", force gen(_w2)

drop if _w2!=3
tab _w2
tab _quintile if folio==50950014 //there is more than one imputation

*keeping one out of 21 imputations
keep if _mi_m==8



*Recoding the income groups

recode _quintile (1/2=1 "first and second income quintile") (3/5=0 "third fourth fifth income quintile"), gen(income_quintile)
tab income_quintile


*******************************
*1. (A) Exposure analysis - Variables DRM
*******************************


*log using "drm_data_analysis_w2.log", replace
*log off



****************
**** Table 1
****************
	
	
	gen extreme_rainfall = 0
	*replace extreme_rainfall=. if v15_03a==98
	replace extreme_rainfall = 1 if (v15_03a == 1)
	
	gen severe_storms = 0
	*replace severe_storms=. if v15_03b==98
	replace severe_storms = 1 if (v15_03b == 1)
	
	gen floods = 0
	*replace floods=. if v15_03c==98
	replace floods = 1 if (v15_03c == 1)
	
	gen hurricanes = 0
	*replace hurricanes=. if v15_03d==98
	replace hurricanes = 1 if (v15_03d == 1)
	
	gen heat_waves = 0
	*replace heat_waves=. if v15_03e==98
	replace heat_waves = 1 if (v15_03e == 1)
	
	gen drought = 0
	*replace drought=. if v15_03f==98
	replace drought = 1 if (v15_03f == 1)
	
	gen wildfires = 0
	*replace wildfires=. if v15_03g==98
	replace wildfires = 1 if (v15_03g == 1)
	
	gen volcanic_eruption = 0
	*replace volcanic_eruption=. if v15_03h==98
	replace volcanic_eruption = 1 if (v15_03h == 1)
	
	gen earthquake = 0
	*replace earthquake=. if v15_03i==98
	replace earthquake = 1 if (v15_03i == 1)
	
	gen landslides = 0
	*replace landslides=. if v15_03j==98
	replace landslides = 1 if (v15_03j == 1)
	
	gen high_sea_swells = 0
	*replace high_sea_swells=. if v15_03k==98
	replace high_sea_swells = 1 if (v15_03k == 1)
	
	gen tsunami = 0
	*replace tsunami=. if v15_03l==98
	replace tsunami = 1 if (v15_03l == 1)
	
	gen other = 0
	*replace other=. if v15_03m==98
	replace other = 1 if (v15_03m == 1)

**TOTAL by income
putexcel set "$out/Tables_DRM_w2.xlsx", sheet("table_1_incometotal") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(13,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh_ph2w2] if   $varhet==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if  $varhet==0
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh_ph2w2], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**URBAN
putexcel set "$out/Tables_DRM_w2.xlsx", sheet("table_1_incomeurban") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(13,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh_ph2w2] if   $varhet==1 & v03_08a==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if  $varhet==0 & v03_08a==1
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh_ph2w2] if v03_08a==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**RURAL
putexcel set "$out/Tables_DRM_w2.xlsx", sheet("table_1_incomerural") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(12,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh_ph2w2] if   $varhet==1 & v03_08a==2
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if  $varhet==0 & v03_08a==2
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh_ph2w2] if v03_08a==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

*******************************************************************************
**Figure 4

tab v03_08a v15_01 [aw=w_hh_ph2w2] if haiti_regions==2, row
tabout v03_08a v15_01 [aw=w_hh_ph2w2] if haiti_regions==2  using tables_w2_drm.xls, c(row) f(1) append

	
**************************************************************
**** Figure 4c
**************************************************************

/*
	gen emergency_plan = 0
	*replace emergency_plan=. if v15_12a==98
	replace emergency_plan = 1 if (v15_12a == 1)
	tab emergency_plan
	
	gen committee = 0
	*replace committee=. if v15_12b==98
	replace committee = 1 if (v15_12b == 1)
	tab committee
	
	gen trained_community = 0
	*replace trained_community=. if v15_12c==98
	replace trained_community = 1 if (v15_12c == 1)
	tab trained_community
	
	gen evacuation_routes = 0
	*replace evacuation_routes=. if v15_12d==98
	replace evacuation_routes = 1 if (v15_12d == 1)
	tab evacuation_routes
	
	gen shelter = 0
	*replace shelter=. if v15_12e==98
	replace shelter = 1 if (v15_12e == 1)
	tab shelter
	*/
	
tab income_quintile emergency_plan 		[iw=w_hh_ph2w2], row nofreq
tab income_quintile committee 			[iw=w_hh_ph2w2], row nofreq
tab income_quintile trained_community 	[iw=w_hh_ph2w2], row nofreq
tab income_quintile evacuation_routes 	[iw=w_hh_ph2w2], row nofreq
tab income_quintile shelter 			[iw=w_hh_ph2w2], row nofreq

tabout income_quintile emergency_plan 			[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout income_quintile committee 				[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout income_quintile trained_community 		[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout income_quintile evacuation_routes 		[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
tabout income_quintile shelter 					[iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append 
	
	
**************************************************************
**** Checking significance for first paragraph third section
**************************************************************
*log on
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate income_quintile [aw=w_hh_ph2w2], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.income_quintile [aw=w_hh_ph2w2], vce(robust)
	
	
	}
*log off

**************************************************************
**** Table 3
**************************************************************
putexcel set "$out/Tables_DRM_w2.xlsx", sheet("table_3") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Evacuation Routes"
putexcel A3="Shelter"
putexcel A4="Trained Community"
putexcel A5="Committee"
putexcel A6="Emergency Plan"


putexcel B1="Urban (mean)"
putexcel C1="Rural (mean)"
putexcel D1="Difference"

cap drop area
recode v03_08a (1=1 "Urban") (2=0 "Rural"), gen(area)

local i=1
global varhet area
mat mat_t1=J(5,4,0) //Defining empty matrix

	foreach var of varlist evacuation_routes shelter trained_community committee emergency_plan    {

		sum `var'  [aw=w_hh_ph2w2] if   $varhet==1 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if  $varhet==0  
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh_ph2w2], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)


**************************************************************
**** Table 3 (paper)
**************************************************************


	**********
	*** Do you have supplies or other things in your home that could be used to help your household in a disaster or emergency?
	**********	
		
	tab v15_05, m
	tab v15_05, nol
	
	gen have_supplies = 0
	*replace have_supplies=. if v15_05==98
	replace have_supplies = 1	if (v15_05 == 1)
	tab have_supplies
	
	
	**********
	*** Have you and your family members ever talked about or planned what you would do in the event of a disaster or emergency?
	**********	
		
	tab v15_07, m
	tab v15_07, nol
	
	gen family_talked = 0
	*replace family_talked=. if v15_07==98	
	replace family_talked = 1	if (v15_07 == 1)
	tab family_talked

	****************
	*** - Compared to just before the pandemic, do you feel that your household is better prepared, equally prepared, or less prepared to deal with a disaster or emergency? 
	****************

	
	tab v15_09, m
	tab v15_09, nol
	
	*Category "zero" will be more/equally prepared or don't know
	gen less_prepared = 0
	replace less_prepared = 1 if (v15_09 ==3)
	tab less_prepared



	
	****************
	*** - Do you feel that your household is very prepared, somewhat prepared, or not prepared to deal with a disaster or emergency at this time?
	****************
	
	tab v15_04, m
	tab v15_04, nol
		
	*zero will be very/somewhat prepared or don't know
	gen not_prepared = 0
	replace not_prepared = 1 if (v15_04 == 3)
	tab not_prepared
	
	*log on

	/*foreach var of varlist have_supplies family_talked not_prepared less_prepared  {

	tabulate income_quintile [aw=w_hh_ph2w2], summarize(`var')
	
	}
	
	foreach var of varlist have_supplies family_talked not_prepared less_prepared  {
	
	reg `var' i.income_quintile [aw=w_hh_ph2w2], vce(robust)
	
	
	}
		
	log off
	log close
*/
*By QUintile.
putexcel set "$out/Tables_DRM_w2.xlsx", sheet("table_3_upper") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Household with supplies"
putexcel A3="The family talked about what you would do in a disaster"
putexcel A4=" Currently not prepared to respond to a disaster"
putexcel A5="Less prepared compared to pre-pandemic"
putexcel B1="Overrall"
putexcel C1="Bottom 40 percent (mean)"
putexcel D1="Top 60 percent (mean)"
putexcel E1="Difference"

local i=1
global income income_quintile
mat mat_t1=J(4,5,0) //Defining empty matrix

	foreach var of varlist have_supplies family_talked not_prepared less_prepared   {

	    sum `var'  [aw=w_hh_ph2w2] 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if   $income==1 
		mat mat_t1[ `i',2]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if  $income==0  
		mat mat_t1[ `i',3]=r(mean)
		mat mat_t1[ `i' ,4]=mat_t1[ `i',3]-mat_t1[ `i',2]
		reg `var'  $income [aw=w_hh_ph2w2], r 
		matrix pval = r(table)
		mat mat_t1[`i',5]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)


*By Area
putexcel set "$out/Tables_DRM_w2.xlsx", sheet("table_4") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Household with supplies"
putexcel A3="The family talked about what you would do in a disaster"
putexcel A4=" Currently not prepared to respond to a disaster"
putexcel A5="Less prepared compared to pre-pandemic"
putexcel B1="Overrall"
putexcel C1="Urban (mean)"
putexcel D1="Rural (mean)"
putexcel E1="Difference"

cap drop area
recode v03_08a (1=1 "Urban") (2=0 "Rural"), gen(area)

local i=1
global varhet area
mat mat_t1=J(4,5,0) //Defining empty matrix

	foreach var of varlist have_supplies family_talked not_prepared less_prepared   {

	    sum `var'  [aw=w_hh_ph2w2] 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if   $varhet==1 
		mat mat_t1[ `i',2]=r(mean)
		sum `var'  [aw=w_hh_ph2w2] if  $varhet==0  
		mat mat_t1[ `i',3]=r(mean)
		mat mat_t1[ `i' ,4]=mat_t1[ `i',3]-mat_t1[ `i',2]
		reg `var'  $varhet [aw=w_hh_ph2w2], r 
		matrix pval = r(table)
		mat mat_t1[`i',5]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**************************************************************
**** Figure 9
**************************************************************
*By Income
tab income_quintile v15_09 [iw=w_hh_ph2w2], row nofreq

tabout income_quintile v15_09 [iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append

*By Area
tab v03_08a v15_09 [iw=w_hh_ph2w2], row nofreq

tabout v03_08a v15_09 [iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append


**************************************************************
****Figure 7 
**************************************************************


tab haiti_regions

tab income_quintile haiti_regions [iw=w_hh_ph2w2], row nofreq
tabout income_quintile haiti_regions [iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append

tab income_quintile v15_01 if haiti_regions==2 [iw=w_hh_ph2w2], row nofreq
tabout income_quintile v15_01 if haiti_regions==2 [iw=w_hh_ph2w2] using tables_w2_drm.xls, c(row) f(1) append
 
reg v15_01 i.income_quintile [aw=w_hh_ph2w2], vce(robust)


**************************************************************
*Summary Statistics: Appendix
**************************************************************
tab household_head_fem [aw=w_hh_ph2w2] //sex
tabout household_head_fem [aw=w_hh_ph2w2]  using tablesw2_ss.xls, c(col) replace

tab age_head [aw=w_hh_ph2w2]  //age
tabout age_head [aw=w_hh_ph2w2]  using tablesw2_ss.xls, c(col) append

tab education [aw=w_hh_ph2w2] //education2
tabout education [aw=w_hh_ph2w2]  using tablesw2_ss.xls, c(col) append

tab _quintile [aw=w_hh_ph2w2] //income
tabout _quintile [aw=w_hh_ph2w2]  using tablesw2_ss.xls, c(col) append

tab area [aw=w_hh_ph2w2] //area
tabout area [aw=w_hh_ph2w2]  using tablesw2_ss.xls, c(col) append

tab haiti_regions [aw=w_hh_ph2w2] //region
tabout haiti_regions [aw=w_hh_ph2w2]  using tablesw2_ss.xls, c(col) append

********************************************************************************
***********     WAVE 3    ******************************************************
********************************************************************************
clear all
set more off

*global rawdata "C:\Users\GUILLERMO\Documents\Jobs\Haiti\DRM\replication\wave_3"

*global data "C:\Users\GUILLERMO\Documents\Jobs\Haiti\DRM\replication\_data"

*global out "C:\Users\GUILLERMO\Documents\Jobs\Haiti\DRM\replication\_out\Wave 3"

use "$rawdata\hfs_2022_haiti_weighted_cases.dta", clear 

*Generation final data base.
*Adjusting the region variable

gen subnatID2 = q03_07
lab def subnatID2 50901  "Ouest" 50902  "Sud-Est" 50903  "Nord" 50904  "Nord-Est" 50905  "Artibonite" 50906  ///
"Centre" 50907  "Sud" 50908  "Grande'Anse" 50909  "Nord-Ouest" 50910  "Nippes"
lab val subnatID2 subnatID2
tab subnatID2, gen(subnat)


recode q03_07 (50901 = 1) (50902 50907 50908 50910 =2) (50903 50904 50909 = 3) (50905 50906 = 4), gen(haiti_regions)

lab def haiti_regions 1  "Ouest" 2 "Southern" 3 "Northern" 4  "Central" 
lab val haiti_regions haiti_regions
tab haiti_regions, gen(region_)


*merge children data sets.
merge 1:m case_id using "$rawdata/hfs_2022_haiti_weighted_children_0_5.dta"

merge 1:m case_id using "$rawdata/hfs_2022_haiti_weighted_children_6_17.dta", gen (_merge2)

save "$data\HAITI_HFS22_W3.dta", replace

********************************************************************************
use "$data\HAITI_HFS22_W3.dta", clear 

cd "$out"

*****************************************************
*Figure 1
*****************************************************

	******************
	*** - What types of natural hazards do you think threaten your home? - Aggregate
	******************

	foreach i in `c(alpha)' {
if "`i'"<="k" {

replace q15_04`i'=0 if q15_04`i'!=1

}
}


encode q15_04l, gen (other)
tab q15_04l
tab other, nol m

replace other=. if other==1
replace other=1 if other==7 | other==8 | other==9 | other==10 | other==11 | other==12 | other==13 | other==14 | other==15 | other==16 ///
| other==17 | other==18 | other==33 | other==34 | other==35 | other==36 | other==37 | other==38 | other==39 | other==40 | other==41 | other==42 | other==43 | other==44 | other==45
replace other=2 if other==2 | other==3 | other==4 | other==5 | other==6 | other==20 | other==21 | other==22 | other==23 | other==24 | other==25 | other==26 | other==27 ///
| other==28 | other==29 | other==30 | other==31 | other==32 | other==43
replace other=98 if other==16 | other==19 | other==33
tab other, nol

recode other (1=1) (2=0) (98=0), gen(others)


	br q15_04* others

	egen hazard=rowtotal(q15_04a q15_04b q15_04c q15_04d q15_04e q15_04f q15_04g q15_04h q15_04i q15_04j q15_04k others)

	br q15_04* others hazard


	tab hazard
	recode hazard (0=0 "0 hazards") (1/2= 1 "1-2 hazards") (3/11=2 "3 or more hazards"), gen(hazard_exp)
	tab hazard_exp [iw=w_hh]

	*output to excel 
	tabout q03_10 hazard_exp [iw=w_hh] using tables_w3_drm.xls, c(row) f(1) replace
	
*****************************************************
*Figure 2
*****************************************************

	
	******************
	*** - What types of natural hazards do you think threaten your home? - Disaggregated
	******************

	foreach i in `c(alpha)' {
	if "`i'"<="k" {

	tab q03_10 q15_04`i', m row nofreq

	*output to excel 
	tabout q03_10 q15_04`i' [iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
		
	}
	}
	

	tab q03_10 others,  row nofreq

	*output to excel 
	tabout q03_10 others [iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append

*****************************************************
*Regressions - Figure 3
*****************************************************


* Sex household head

tab q03_01
gen household_head_fem=.
replace household_head_fem=1 if (q03_06==2 & q03_01==1) | q03_14==2
replace household_head_fem=0 if (q03_06==1 & q03_01==1) | q03_14==1
tab household_head_fem 
label def household_head_fem 1 "Female" 0 "Male"
label val household_head_fem household_head_fem


*household head age
gen edad_proxy = 2022 - q03_04a + 1 	
label var edad_proxy "Edad aprox. en 2022"
tab edad_proxy
replace edad_proxy=. if edad_proxy==-7976 | edad_proxy==123
tab edad_proxy
replace edad_proxy=q03_05 if edad_proxy==.
replace edad_proxy=q03_05 if (edad_proxy!=. & q03_05!=.)
tab edad_proxy
*br edad_proxy q03_05
replace edad_proxy=. if edad_proxy==99
recode edad_proxy (18/29=1 "18 to 29") (30/49=2 "30 to 49") (50/78=3 "50+"), gen(age_head)
tab age_head

*children 0-17 at home
tab q07_16, m
recode q07_16 (0=0 "no children") (1/2=1 "1-2 children") (3/9=3 "3+ children"), gen(children)
tab children, m


*education of head of household
recode q03_11 (1/8 = 1) (9/15 = 2) (16 = 3) (99 = .), gen(education)
lab def education 1 "No Educ./Primary" 2 "Secondary" 3 "Tertiary or more"
lab val education education
replace education=0 if q03_01!=1
replace education=1 if q03_13>=1 & q03_13<=8
replace education=2 if q03_13>=9 & q03_13<=15
replace education=3 if q03_13==16
replace education=. if q03_13==99
tab education


*location
tab haiti_regions
recode haiti_regions (1=1 "Ouest") (2=2 "Southern") (3=3 "Northern") (4=4 "Central"), gen (region)

*area
tab q03_10
recode q03_10 (1=1 "Urban") (2=2 "Rural"), gen(area)
*regression *Affected by Earthquake

tab q15_01, nol
replace q15_01=0 if q15_01==2 

probit q15_01 i.household_head_fem ib(last).age_head i.children i.education i.region i.area [iw=w_hh], vce(robust)
estimates store earthquake

* Compute margins

estimates restore earthquake
margins, dydx(*) vce(unconditional) post
estimates store marg_earthquake


coefplot marg_earthquake, drop(_cons) ///
	headings(1.household_head_fem = `""{bf: Head of household: sex}" "{it:(Ref.: male)}"' ///
			 1.age_head = `""{bf: Age group}" "{it:(Ref.: 50+ years)}"'  ///
			 1.children = `""{bf: Number of children (0-17)}" "{it:(Ref.: no children)}"' ///
			 2.education = `""{bf: Educational attainment}" "{it:(Ref.: Primary or less)}"' ///
			 2.region = `""{bf: Region}" "{it:(Ref.: Ouest)}"' 2.area =`""{bf: Area}" "{it:(Ref.: Urban)}"', labsize(small))  xline(0, lcolor(navy) lpattern(dash)) ///
			subtitle("Households affected by the August, 2021 earthquake", size(medsmall) color(black) margin(small) ///
			 box bmargin(small) lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(medsmall) ticks tlength(medium)) ///
			 scheme(sj) ymtick(, labels labsize(medsmall)) 
graph export "$out/graph1_w3.png", replace
*graph save 	"C:\Users\mycar\OneDrive\Escritorio\Gender Assessment Haiti\Deep dives\Aditional_graphs\WVS\graph1", replace



*********************************************************************
*First paragraph Section 3 - Figure 4b - Does your community have...
*********************************************************************

	
	gen emergency_plan = 0
	*replace emergency_plan=. if q15_13a==98
	replace emergency_plan = 1 if (q15_13a == 1)
	tab emergency_plan
	tab q03_10 emergency_plan [iw=w_hh], row nofreq
	
	gen committee = 0
	*replace committee=. if v15_12b==98
	replace committee = 1 if (q15_13b == 1 | q15_13b == 2)
	tab committee
	tab q03_10 committee [iw=w_hh], row nofreq
	
	gen trained_community = 0
	*replace trained_community=. if v15_12c==98
	replace trained_community = 1 if (q15_13c == 1)
	tab trained_community
	tab q03_10 trained_community [iw=w_hh], row nofreq
	
	gen evacuation_routes = 0
	*replace evacuation_routes=. if v15_12d==98
	replace evacuation_routes = 1 if (q15_13d == 1)
	tab evacuation_routes
	tab q03_10 evacuation_routes [iw=w_hh], row nofreq
	
	gen shelter = 0
	*replace shelter=. if v15_12e==98
	replace shelter = 1 if (q15_13e == 1)
	tab shelter
	tab q03_10 shelter [iw=w_hh], row nofreq
	
*By household head gender
tab household_head_fem [iw=w_hh]


tab household_head_fem emergency_plan 		[iw=w_hh], row nofreq
tab household_head_fem committee 			[iw=w_hh], row nofreq
tab household_head_fem trained_community 	[iw=w_hh], row nofreq
tab household_head_fem evacuation_routes 	[iw=w_hh], row nofreq
tab household_head_fem shelter 				[iw=w_hh], row nofreq

tabout household_head_fem emergency_plan 		[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout household_head_fem committee 			[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout household_head_fem trained_community 	[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout household_head_fem evacuation_routes 	[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout household_head_fem shelter 				[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append 

*by area

tabout q03_10 emergency_plan 		[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout q03_10 committee 			[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout q03_10 trained_community 	[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout q03_10 evacuation_routes 	[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout q03_10 shelter 				[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append 

*********************************************************************************************************************************
**** Not in the paper but checking results on significance by sex of head of household head for first paragraph third section
*********************************************************************************************************************************



	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate household_head_fem [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.household_head_fem [aw=w_hh], vce(robust)
	
	
	}


	
******************************************************
*Regressions - Figure 10 - Correlates with prepardness
******************************************************


	*Outcome variable - Prepared to deal with a disaster
	
	****************
	*** - Do you feel that your household is very prepared, somewhat prepared, or not prepared to deal with a disaster or emergency at this time?
	****************
	
	tab q15_05, m
	tab q15_05, nol
	
	/******************
	*** - Does your household have cable internet and/or WiFi? - Not available for wave 3
	******************	
	
	tab v11_08, m
	tab v11_08, nol
	
	gen internet = 0
	replace internet=. if v11_08==98
	replace internet = 1 if (v11_08 == 1)
	tab internet
	label def internet 1 "Yes" 0 "No"
	label val internet internet
	*/
	
	*Do you have a laptop that works
	tab q12_036
	recode q12_036 (1=1) (2/3=0), gen(laptop)
	tab laptop
	label def laptop 1 "Yes" 0 "No"
	label val laptop laptop
	
	*One will be very or somewhat prepared and zero will be not prepared or don't know
	gen prepared = 0
	replace prepared = 1 if (q15_05 == 1 | q15_05 == 2)
	tab prepared

	*regression *households prepared to deal with a disaster
	probit prepared i.household_head_fem ib(last).age_head i.children i.education i.region i.area i.laptop  [iw=w_hh], vce(robust)
	estimates store prepared

	* Compute margins

	estimates restore prepared
	margins, dydx(*) vce(unconditional) post
	estimates store marg_prepared
/*
	coefplot marg_prepared, drop(_cons) ///
		headings(1.household_head_fem = `""{bf: Head of household: sex}" "{it:(Ref.: male)}"' ///
				 1.age_head = `""{bf: Age group}" "{it:(Ref.: 50+ years)}"'  ///
				 1.children = `""{bf: Number of children (0-17)}" "{it:(Ref.: no children)}"' ///
				 2.education = `""{bf: Educational attainment}" "{it:(Ref.: Primary or less)}"' ///
				 1.laptop = `""{bf: Laptop}" "{it:(Ref.: No)}"' ///
				 2.region = `""{bf: Region}" "{it:(Ref.: Ouest)}"' ///
				 2.area= `""{bf: Area}" "{it:(Ref.: Urban)}"', labsize(vsmall))  xline(0, lcolor(navy) lpattern(dash)) ///
				 subtitle("Households prepared to deal with a disaster", size(vsmall) color(black) margin(small) box bmargin(small) ///
				 lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(small) ticks tlength(small)) ///
				 scheme(sj) ymtick(, labels labsize(small))
				 */
	coefplot marg_prepared, drop(_cons) ///
		headings(1.household_head_fem = `"{bf: Head of household: sex}"' ///
				 1.age_head = `"{bf: Age group}"'  ///
				 1.children = `"{bf: Number of children (0-17)}"' ///
				 2.education = `"{bf: Educational attainment}"' ///
				 1.laptop = `"{bf: Internet access}"' ///
				 2.region = `"{bf: Region}"' ///
				 2.area = `"{bf: Area}"', labsize(medium_small))  xline(0, lcolor(navy) lpattern(dash)) ///
				 subtitle("Households prepared to deal with a disaster", size(medium_small) color(black) margin(small) ///
				 box bmargin(small) lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(medium_small) ticks tlength(tiny_small) alternate) ///
				 scheme(sj) ymtick(, labels labsize(medium_small))	
graph export "$out/graph2_w3.png", replace

	*graph save 	"C:\Users\mycar\OneDrive\Escritorio\Gender Assessment Haiti\Deep dives\Aditional_graphs\WVS\graph1", replace	

	
*Figure 8 on shelters by type of natural hazard *******************************************

foreach var of varlist q15_04a q15_04b q15_04c q15_04d q15_04e q15_04f q15_04g q15_04h q15_04i q15_04j q15_04k { 

tab `var' q15_13e [iw=w_hh], row 

}

	*output to excel 
	tabout q15_04a q15_13e [iw=w_hh] using tables_shelter_w2.xls, c(row) f(1) replace

	foreach i in `c(alpha)' {
	if "`i'"<="k" {

	tab q15_04`i' q15_13e, row nofreq

	*output to excel 
	tabout q15_04`i' q15_13e [iw=w_hh] using tables_shelter_w3.xls, c(row) f(1) append
		
	}
	}

 
	
*########################################################################################################
*										   WAVE 3  Income quintile analysis                             *
*########################################################################################################


********************
*0. Load Data
********************
merge 1:m case_id using "$data\imputed_all_2.dta", force gen(i_merge)

*tab _quintile if case_id==50925313 //there is more than one imputation

*keeping one out of 20 imputations
keep if _mi_m==8



*Recoding the income groups

recode _quintile (1/2=1 "first and second income quintile") (3/5=0 "third fourth fifth income quintile"), gen(income_quintile)
tab income_quintile


*******************************************
*1. (A) Exposure analysis - Variables DRM
*******************************************


*log using "drm_data_analysis_w3.log", replace
*log off



****************
**** Table 1
****************
	
	
	gen extreme_rainfall = 0
	*replace extreme_rainfall=. if v15_03a==98
	replace extreme_rainfall = 1 if (q15_04a == 1)
	
	gen severe_storms = 0
	*replace severe_storms=. if v15_03b==98
	replace severe_storms = 1 if (q15_04b == 1)
	
	gen floods = 0
	*replace floods=. if v15_03c==98
	replace floods = 1 if (q15_04c == 1)
	
	gen hurricanes = 0
	*replace hurricanes=. if v15_03d==98
	replace hurricanes = 1 if (q15_04d == 1)
	
	gen heat_waves = 0
	*replace heat_waves=. if v15_03e==98
	replace heat_waves = 1 if (q15_04e == 1)
	
	gen drought = 0
	*replace drought=. if v15_03f==98
	replace drought = 1 if (q15_04f == 1)
	
	gen wildfires = 0
	*replace wildfires=. if v15_03g==98
	replace wildfires = 1 if (q15_04g == 1)
	
	/*gen volcanic_eruption = 0 - Not available
	*replace volcanic_eruption=. if v15_03h==98
	replace volcanic_eruption = 1 if (v15_03h == 1)
	*/
	
	gen earthquake = 0
	*replace earthquake=. if v15_03i==98
	replace earthquake = 1 if (q15_04h == 1)
	
	gen landslides = 0
	*replace landslides=. if v15_03j==98
	replace landslides = 1 if (q15_04i == 1)
	
	gen high_sea_swells = 0
	*replace high_sea_swells=. if v15_03k==98
	replace high_sea_swells = 1 if (q15_04j == 1)
	
	gen tsunami = 0
	*replace tsunami=. if v15_03l==98
	replace tsunami = 1 if (q15_04k == 1)

cap drop other
encode q15_04l, gen (other)
tab q15_04l
tab other, nol m

replace other=. if other==1
replace other=1 if other==7 | other==8 | other==9 | other==10 | other==11 | other==12 | other==13 | other==14 | other==15 | other==16 ///
| other==17 | other==18 | other==33 | other==34 | other==35 | other==36 | other==37 | other==38 | other==39 | other==40 | other==41 | other==42 | other==43 | other==44 | other==45
replace other=2 if other==2 | other==3 | other==4 | other==5 | other==6 | other==20 | other==21 | other==22 | other==23 | other==24 | other==25 | other==26 | other==27 ///
| other==28 | other==29 | other==30 | other==31 | other==32 | other==43
replace other=98 if other==16 | other==19 | other==33
tab other, nol

cap drop others
recode other (1=1) (2=0) (98=0), gen(others)


	*education of head of household
	recode q03_11 (1/8 = 1) (9/16 = 0) (99 = .), gen(education2)
	lab def education2 1 "No Educ./Primary" 0 "Secondary or more"
	lab val education2 education2
	replace education2=0 if q03_01!=1
	replace education2=1 if q03_13>=1 & q03_13<=8
	replace education2=0 if q03_13>=9 & q03_13<=16
	replace education2=. if q03_13==99
	tab education2
	

*log on	

	*by income
**TOTAL by income
putexcel set "$out/Tables_DRM_w3.xlsx", sheet("table_1_incometotal") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(13,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  others {

		sum `var'  [iw=w_hh] if   $varhet==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [iw=w_hh] if  $varhet==0
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [iw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**URBAN
putexcel set "$out/Tables_DRM_w3.xlsx", sheet("table_1_incomeurban") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(13,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  others {

		sum `var'  [iw=w_hh] if   $varhet==1 & q03_10==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [iw=w_hh] if  $varhet==0 & q03_10==1
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [iw=w_hh] if q03_10==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**RURAL
putexcel set "$out/Tables_DRM_w3.xlsx", sheet("table_1_incomerural") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(12,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  others {

		sum `var'  [iw=w_hh] if   $varhet==1 & q03_10==2
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [iw=w_hh] if  $varhet==0 & q03_10==2
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [iw=w_hh] if q03_10==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

	*by education
	
	foreach var of varlist extreme_rainfall severe_storms floods hurricanes heat_waves drought wildfires earthquake landslides high_sea_swells tsunami others {

	tabulate education2 [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist extreme_rainfall severe_storms floods hurricanes heat_waves drought wildfires earthquake landslides high_sea_swells tsunami others {
	
	reg `var' i.education2 [aw=w_hh], vce(robust)
	
	
	}
	
*log off


*******************************************************************************
**Figure 4

tab q03_10 q15_01  [aw=w_hh] if haiti_regions==2, row
tabout q03_10 q15_01 [aw=w_hh] if haiti_regions==2  using tables_w3_drm.xls, c(row) f(1) append

**************************************************************
**** Figure 4d
**************************************************************

tab income_quintile emergency_plan 			[iw=w_hh], row nofreq
tab income_quintile committee 				[iw=w_hh], row nofreq
tab income_quintile trained_community 		[iw=w_hh], row nofreq
tab income_quintile evacuation_routes 		[iw=w_hh], row nofreq
tab income_quintile shelter 				[iw=w_hh], row nofreq

tabout income_quintile emergency_plan 		[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout income_quintile committee 			[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout income_quintile trained_community 	[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout income_quintile evacuation_routes 	[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append
tabout income_quintile shelter 				[iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append 
	
	
**************************************************************
**** Chechking significance for first paragraph third section
**************************************************************
*log on

*by education
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate education2 [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.education2 [aw=w_hh], vce(robust)
	
	
	}
	
*by income
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate income_quintile [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.income_quintile [aw=w_hh], vce(robust)
	
	
	}

*log off

**************************************************************
**** Table 3
**************************************************************
**RURAL
putexcel set "$out/Tables_DRM_w3.xlsx", sheet("table_3") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Evacuation Routes"
putexcel A3="Shelter"
putexcel A4="Trained Community"
putexcel A5="Committee"
putexcel A6="Emergency Plan"


putexcel B1="Urban (mean)"
putexcel C1="Rural (mean)"
putexcel D1="Difference"

cap drop area
recode q03_10 (1=1 "Urban") (2=0 "Rural"), gen(area)

local i=1
global varhet area
mat mat_t1=J(5,4,0) //Defining empty matrix

	foreach var of varlist evacuation_routes shelter trained_community committee emergency_plan    {

		sum `var'  [aw=w_hh] if   $varhet==1 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0  
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)
**************************************************************
**** Table 3 (paper)
**************************************************************


	**********
	*** Do you have supplies or other things in your home that could be used to help your household in a disaster or emergency?
	**********	
		
	tab q15_06, m
	tab q15_06, nol
	
	gen have_supplies = 0
	*replace have_supplies=. if v15_05==98
	replace have_supplies = 1	if (q15_06 == 1)
	tab have_supplies
	
	
	**********
	*** Have you and your family members ever talked about or planned what you would do in the event of a disaster or emergency?
	**********	
		
	tab q15_08, m
	tab q15_08, nol
	
	gen family_talked = 0
	*replace family_talked=. if v15_07==98	
	replace family_talked = 1	if (q15_08 == 1)
	tab family_talked

	****************
	*** - Compared to just before the pandemic, do you feel that your household is better prepared, equally prepared, or less prepared to deal with a disaster or emergency? 
	****************

	
	tab q15_10, m
	tab q15_10, nol
	
	*Category "zero" will be more/equally prepared or don't know
	gen less_prepared = 0
	replace less_prepared = 1 if (q15_10 ==3)
	tab less_prepared



	
	****************
	*** - Do you feel that your household is very prepared, somewhat prepared, or not prepared to deal with a disaster or emergency at this time?
	****************
	
	tab q15_05, m
	tab q15_05, nol
		
	*zero will be very/somewhat prepared or don't know
	gen not_prepared = 0
	replace not_prepared = 1 if (q15_05 == 3)
	tab not_prepared
/*	
log on	

	foreach var of varlist have_supplies family_talked not_prepared less_prepared  {

	tabulate income_quintile [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist have_supplies family_talked not_prepared less_prepared  {
	
	reg `var' i.income_quintile [aw=w_hh], vce(robust)
	
	
	}
		
log off
log close */

*By QUintile.
putexcel set "$out/Tables_DRM_w3.xlsx", sheet("table_3_upper") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Household with supplies"
putexcel A3="The family talked about what you would do in a disaster"
putexcel A4=" Currently not prepared to respond to a disaster"
putexcel A5="Less prepared compared to pre-pandemic"
putexcel B1="Overrall"
putexcel C1="Bottom 40 percent (mean)"
putexcel D1="Top 60 percent (mean)"
putexcel E1="Difference"

local i=1
global income income_quintile
mat mat_t1=J(4,5,0) //Defining empty matrix

	foreach var of varlist have_supplies family_talked not_prepared less_prepared   {

	    sum `var'  [aw=w_hh] 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if   $income==1 
		mat mat_t1[ `i',2]=r(mean)
		sum `var'  [aw=w_hh] if  $income==0  
		mat mat_t1[ `i',3]=r(mean)
		mat mat_t1[ `i' ,4]=mat_t1[ `i',3]-mat_t1[ `i',2]
		reg `var'  $income [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',5]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)


*By Area
putexcel set "$out/Tables_DRM_w3.xlsx", sheet("table_4") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Household with supplies"
putexcel A3="The family talked about what you would do in a disaster"
putexcel A4=" Currently not prepared to respond to a disaster"
putexcel A5="Less prepared compared to pre-pandemic"
putexcel B1="Overrall"
putexcel C1="Urban (mean)"
putexcel D1="Rural (mean)"
putexcel E1="Difference"

cap drop area
recode q03_10 (1=1 "Urban") (2=0 "Rural"), gen(area)

local i=1
global varhet area
mat mat_t1=J(4,5,0) //Defining empty matrix

	foreach var of varlist have_supplies family_talked not_prepared less_prepared   {

	    sum `var'  [aw=w_hh] 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if   $varhet==1 
		mat mat_t1[ `i',2]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0  
		mat mat_t1[ `i',3]=r(mean)
		mat mat_t1[ `i' ,4]=mat_t1[ `i',3]-mat_t1[ `i',2]
		reg `var'  $varhet [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',5]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**************************************************************
**** Figure 5
**************************************************************
*By income
tab income_quintile q15_10 [iw=w_hh], row nofreq

tabout income_quintile q15_10 [iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append

*By Area

tab q03_10 q15_10 [iw=w_hh], row nofreq

tabout q03_10 q15_10 [iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append


**************************************************************
****Figure 7 
**************************************************************


tab haiti_regions

tab income_quintile haiti_regions [iw=w_hh], row nofreq
tabout income_quintile haiti_regions [iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append

tab income_quintile q15_01 if haiti_regions==2 [iw=w_hh], row nofreq
tabout income_quintile q15_01 if haiti_regions==2 [iw=w_hh] using tables_w3_drm.xls, c(row) f(1) append

reg q15_01 i.income_quintile [aw=w_hh] if haiti_regions==2, vce(robust)

**************************************************************
*Summary Statistics: Appendix
**************************************************************
tab household_head_fem [aw=w_hh] //sex
tabout household_head_fem [aw=w_hh]  using tablesw3_ss.xls, c(col) replace

tab age_head [aw=w_hh]  //age
tabout age_head [aw=w_hh]  using tablesw3_ss.xls, c(col) append

tab education [aw=w_hh] //education2
tabout education [aw=w_hh]  using tablesw3_ss.xls, c(col) append

tab _quintile [aw=w_hh] //income
tabout _quintile [aw=w_hh]  using tablesw3_ss.xls, c(col) append

tab area [aw=w_hh] //area
tabout area [aw=w_hh]  using tablesw3_ss.xls, c(col) append

tab haiti_regions [aw=w_hh] //region
tabout haiti_regions [aw=w_hh]  using tablesw3_ss.xls, c(col) append

********************************************************************************
***********     WAVE 4    ******************************************************
********************************************************************************
clear all
set more off

*global rawdata "C:\Users\GUILLERMO\Documents\Jobs\Haiti\DRM\replication\wave_4"

*global data "C:\Users\GUILLERMO\Documents\Jobs\Haiti\DRM\replication\_data"

*global out "C:\Users\GUILLERMO\Documents\Jobs\Haiti\DRM\replication\_out\Wave 4"

use "$rawdata\hfs_2023_haiti_weighted_cases.dta", clear 

*Generation final data base.
*Adjusting the region variable

gen subnatID2 = q03_07
lab def subnatID2 50901  "Ouest" 50902  "Sud-Est" 50903  "Nord" 50904  "Nord-Est" 50905  "Artibonite" 50906  ///
"Centre" 50907  "Sud" 50908  "Grande'Anse" 50909  "Nord-Ouest" 50910  "Nippes"
lab val subnatID2 subnatID2
tab subnatID2, gen(subnat)


recode q03_07 (50901 = 1) (50902 50907 50908 50910 =2) (50903 50904 50909 = 3) (50905 50906 = 4), gen(haiti_regions)

lab def haiti_regions 1  "Ouest" 2 "Southern" 3 "Northern" 4  "Central" 
lab val haiti_regions haiti_regions
tab haiti_regions, gen(region_)


*merge children data sets.
merge 1:m case_id using "$rawdata/hfs_2023_haiti_weighted_children_0_5.dta"

merge 1:m case_id using "$rawdata/hfs_2023_haiti_weighted_children_6_17.dta", gen (_merge2)

save "$data\HAITI_HFS23_W4.dta", replace

********************************************************************************
use "$data\HAITI_HFS23_W4.dta", clear 

cd "$out"

*****************************************************
*Figure 1
*****************************************************

	******************
	*** - What types of natural hazards do you think threaten your home? - Aggregate
	******************

		foreach i in `c(alpha)' {
	if "`i'"<="k" {

	replace q15_04`i'=0 if q15_04`i'!=1

	}
	}


	encode q15_04l, gen (other)
	tab q15_04l
	tab other, nol m

replace other=0 if other==1 | other==2 | other==3 | other==4 | other==9 | other==10 | other==11 | other==12 | other==14
replace other=1 if other==5 | other==6 | other==7 | other==8 | other==13 | other==15 | other==16 | other==17 | other==18 | other==19 | other==20
lab define others 1 "yes" 0 "no"
lab val other others
tab other


	br q15_04* other

	egen hazard=rowtotal(q15_04a q15_04b q15_04c q15_04d q15_04e q15_04f q15_04g q15_04h q15_04i q15_04j q15_04k other)

	br q15_04* other hazard


	tab hazard
	recode hazard (0=0 "0 hazards") (1/2= 1 "1-2 hazards") (3/12=2 "3 or more hazards"), gen(hazard_exp)
	tab hazard_exp [iw=w_hh]

	*output to excel 
	tabout q03_10 hazard_exp [iw=w_hh] using tables_w4_drm.xls, c(row) f(1) replace
	
*****************************************************
*Figure 2
*****************************************************

	
	******************
	*** - What types of natural hazards do you think threaten your home? - Disaggregated
	******************

	foreach i in `c(alpha)' {
	if "`i'"<="k" {

	tab q03_10 q15_04`i' [iw=w_hh], m row nofreq

	*output to excel 
	tabout q03_10 q15_04`i' [iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
		
	}
	}
	
	tab q03_10 other,  row nofreq

	*output to excel 
	tabout q03_10 other [iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append

*****************************************************
*Regressions - Figure 3
*****************************************************


* Sex household head

tab q03_01
gen household_head_fem=.
replace household_head_fem=1 if (q03_06==2 & q03_01==1) | q03_14==2
replace household_head_fem=0 if (q03_06==1 & q03_01==1) | q03_14==1
tab household_head_fem 
label def household_head_fem 1 "Female" 0 "Male"
label val household_head_fem household_head_fem


*household head age
gen edad_proxy = 2023 - q03_04a + 1 	
label var edad_proxy "Edad aprox. en 2023"
tab edad_proxy
replace edad_proxy=. if edad_proxy==-7975
tab edad_proxy
replace edad_proxy=q03_05 if edad_proxy==.
replace edad_proxy=q03_05 if (edad_proxy!=. & q03_05!=.)
tab edad_proxy
*br edad_proxy q03_05
replace edad_proxy=. if edad_proxy==99
recode edad_proxy (18/29=1 "18 to 29") (30/49=2 "30 to 49") (50/124=3 "50+"), gen(age_head)
tab age_head

*children 0-17 at home
tab q07_16, m
recode q07_16 (0=0 "no children") (1/2=1 "1-2 children") (3/8=3 "3+ children"), gen(children)
tab children, m


*education of head of household
recode q03_11 (1/8 = 1) (9/15 = 2) (16 = 3) (99 = .), gen(education)
lab def education 1 "No Educ./Primary" 2 "Secondary" 3 "Tertiary or more"
lab val education education
replace education=0 if q03_01!=1
replace education=1 if q03_13>=1 & q03_13<=8
replace education=2 if q03_13>=9 & q03_13<=15
replace education=3 if q03_13==16
replace education=. if q03_13==99
tab education

	

*location
tab haiti_regions
recode haiti_regions (1=1 "Ouest") (2=2 "Southern") (3=3 "Northern") (4=4 "Central"), gen (region)

*area
tab q03_10
recode q03_10 (1=1 "Urban") (2=2 "Rural"), gen(area)

*regression *Affected by Earthquake

tab q15_01, nol
replace q15_01=0 if q15_01==2 

probit q15_01 i.household_head_fem ib(last).age_head i.children i.education i.region i.area [iw=w_hh], vce(robust)
estimates store earthquake

* Compute margins

estimates restore earthquake
margins, dydx(*) vce(unconditional) post
estimates store marg_earthquake

coefplot marg_earthquake, drop(_cons) ///
	headings(1.household_head_fem = `""{bf: Head of household: sex}" "{it:(Ref.: male)}"' ///
			 1.age_head = `""{bf: Age group}" "{it:(Ref.: 50+ years)}"'  ///
			 1.children = `""{bf: Number of children (0-17)}" "{it:(Ref.: no children)}"' ///
			 2.education = `""{bf: Educational attainment}" "{it:(Ref.: Primary or less)}"' ///
			 2.region = `""{bf: Region}" "{it:(Ref.: Ouest)}"' 2.area =`""{bf: Area}" "{it:(Ref.: Urban)}"', labsize(small))  xline(0, lcolor(navy) lpattern(dash)) ///
			subtitle("Households affected by the August, 2021 earthquake", size(medsmall) color(black) margin(small) ///
			 box bmargin(small) lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(medsmall) ticks tlength(medium)) ///
			 scheme(sj) ymtick(, labels labsize(medsmall)) 
graph export "$out/graph1_w4.png", replace

*graph save 	"C:\Users\mycar\OneDrive\Escritorio\Gender Assessment Haiti\Deep dives\Aditional_graphs\WVS\graph1", replace



*********************************************************************
*First paragraph Section 3 - Figure 4b - Does your community have...
*********************************************************************

	
	gen emergency_plan = 0
	*replace emergency_plan=. if q15_13a==98
	replace emergency_plan = 1 if (q15_13a == 1)
	tab emergency_plan
	tab q03_10 emergency_plan [iw=w_hh], row nofreq
	
	gen committee = 0
	*replace committee=. if v15_12b==98
	replace committee = 1 if (q15_13b == 1 | q15_13b == 2)
	tab committee
	tab q03_10 committee [iw=w_hh], row nofreq
	
	gen trained_community = 0
	*replace trained_community=. if v15_12c==98
	replace trained_community = 1 if (q15_13c == 1)
	tab trained_community
	tab q03_10 trained_community [iw=w_hh], row nofreq
	
	gen evacuation_routes = 0
	*replace evacuation_routes=. if v15_12d==98
	replace evacuation_routes = 1 if (q15_13d == 1)
	tab evacuation_routes
	tab q03_10 evacuation_routes [iw=w_hh], row nofreq
	
	gen shelter = 0
	*replace shelter=. if v15_12e==98
	replace shelter = 1 if (q15_13e == 1)
	tab shelter
	tab q03_10 shelter [iw=w_hh], row nofreq
	
*by household head gender 
tab household_head_fem [iw=w_hh]


tab household_head_fem emergency_plan 		[iw=w_hh], row nofreq
tab household_head_fem committee 			[iw=w_hh], row nofreq
tab household_head_fem trained_community 	[iw=w_hh], row nofreq
tab household_head_fem evacuation_routes 	[iw=w_hh], row nofreq
tab household_head_fem shelter 				[iw=w_hh], row nofreq

tabout household_head_fem emergency_plan 		[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout household_head_fem committee 			[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout household_head_fem trained_community 	[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout household_head_fem evacuation_routes 	[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout household_head_fem shelter 				[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append 

*by area

tabout q03_10 emergency_plan 		[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout q03_10 committee 			[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout q03_10 trained_community 	[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout q03_10 evacuation_routes 	[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout q03_10 shelter 				[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append

*********************************************************************************************************************************
**** Not in the paper but checking results on significance by sex of head of household head for first paragraph third section
*********************************************************************************************************************************



	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate household_head_fem [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.household_head_fem [aw=w_hh], vce(robust)
	
	
	}


	
******************************************************
*Regressions - Figure 10 - Correlates with prepardness
******************************************************


	*Outcome variable - Prepared to deal with a disaster
	
	****************
	*** - Do you feel that your household is very prepared, somewhat prepared, or not prepared to deal with a disaster or emergency at this time?
	****************
	
	tab q15_05, m
	tab q15_05, nol
	
	/******************
	*** - Does your household have cable internet and/or WiFi? - Not available for wave 3
	******************	
	
	tab v11_08, m
	tab v11_08, nol
	
	gen internet = 0
	replace internet=. if v11_08==98
	replace internet = 1 if (v11_08 == 1)
	tab internet
	label def internet 1 "Yes" 0 "No"
	label val internet internet
	*/
	
	*Do you have a laptop that works
	tab q12_036
	recode q12_036 (1=1) (2/3=0), gen(laptop)
	tab laptop
	label def laptop 1 "Yes" 0 "No"
	label val laptop laptop
	
	*One will be very or somewhat prepared and zero will be not prepared or don't know
	gen prepared = 0
	replace prepared = 1 if (q15_05 == 1 | q15_05 == 2)
	tab prepared

	*regression *households prepared to deal with a disaster
	probit prepared i.household_head_fem ib(last).age_head i.children i.education i.region i.area i.laptop [iw=w_hh], vce(robust)
	estimates store prepared

	* Compute margins

	estimates restore prepared
	margins, dydx(*) vce(unconditional) post
	estimates store marg_prepared
/*
	coefplot marg_prepared, drop(_cons) ///
		headings(1.household_head_fem = `""{bf: Head of household: sex}" "{it:(Ref.: male)}"' ///
				 1.age_head = `""{bf: Age group}" "{it:(Ref.: 50+ years)}"'  ///
				 1.children = `""{bf: Number of children (0-17)}" "{it:(Ref.: no children)}"' ///
				 2.education = `""{bf: Educational attainment}" "{it:(Ref.: Primary or less)}"' ///
				 1.laptop = `""{bf: Laptop}" "{it:(Ref.: No)}"' ///
				 2.haiti_regions = `""{bf: Region}" "{it:(Ref.: Ouest)}"' ///
				 2.area= `""{bf: Area}" "{it:(Ref.: Urban)}"', labsize(vsmall))  xline(0, lcolor(navy) lpattern(dash)) ///
				 subtitle("Households prepared to deal with a disaster", size(small) color(black) margin(small) box bmargin(small) ///
				 lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(small) ticks tlength(small)) ///
				 scheme(sj) ymtick(, labels labsize(small))
				 */
				 	coefplot marg_prepared, drop(_cons) ///
		headings(1.household_head_fem = `"{bf: Head of household: sex}"' ///
				 1.age_head = `"{bf: Age group}"'  ///
				 1.children = `"{bf: Number of children (0-17)}"' ///
				 2.education = `"{bf: Educational attainment}"' ///
				 1.laptop = `"{bf: Internet access}"' ///
				 2.region = `"{bf: Region}"' ///
				 2.area = `"{bf: Area}"', labsize(medium_small))  xline(0, lcolor(navy) lpattern(dash)) ///
				 subtitle("Households prepared to deal with a disaster", size(medium_small) color(black) margin(small) ///
				 box bmargin(small) lwidth(medium) lcolor(navy)) legend(off) ylabel(, labels labsize(medium_small) ticks tlength(tiny_small) alternate) ///
				 scheme(sj) ymtick(, labels labsize(medium_small))	
graph export "$out/graph2_w4.png", replace

	*graph save 	"C:\Users\mycar\OneDrive\Escritorio\Gender Assessment Haiti\Deep dives\Aditional_graphs\WVS\graph1", replace	

	
*Figure 8 on shelters by type of natural hazard *******************************************

foreach var of varlist q15_04a q15_04b q15_04c q15_04d q15_04e q15_04f q15_04g q15_04h q15_04i q15_04j q15_04k { 

tab `var' q15_13e [iw=w_hh], row nof

}

	*output to excel 
	tabout q15_04a q15_13e [iw=w_hh] using tables_shelter_w4.xls, c(row) f(1) replace

	foreach i in `c(alpha)' {
	if "`i'"<="k" {

	tab q15_04`i' q15_13e [iw=w_hh], row nofreq

	*output to excel 
	tabout q15_04`i' q15_13e [iw=w_hh] using tables_shelter_w4.xls, c(row) f(1) append
		
	}
	}
*urban
		foreach i in `c(alpha)' {
	if "`i'"<="k" {

	tab q15_04`i' q15_13e [iw=w_hh], row nofreq

	*output to excel 
	tabout q15_04`i' q15_13e [iw=w_hh] if q03_10==1 using tables_shelter_w4.xls, c(row) f(1) append
		
	}
	}
	
	*rural
		foreach i in `c(alpha)' {
	if "`i'"<="k" {

	tab q15_04`i' q15_13e [iw=w_hh], row nofreq

	*output to excel 
	tabout q15_04`i' q15_13e [iw=w_hh] if q03_10==2 using tables_shelter_w4.xls, c(row) f(1) append
		
	}
	}
	
*########################################################################################################
*										   WAVE 4  Income quintile analysis                             *
*########################################################################################################


********************
*0. Load Data
********************


set more off
clear all


*global data_w4 "C:\Users\mycar\OneDrive\Escritorio\Gender Assessment Haiti\HFPS2021\Wave 4\_data"
*global out "C:\Users\GUILLERMO\Documents\Jobs\Haiti\DRM\replication\_out\Wave 4"



use "$data\HAITI_HFS23_W4.dta", clear
cd "$out"
merge 1:m case_id using "$data\imputed_all_2_W4.dta", force gen(i_merge)

tab _quintile if case_id==50910001 //there is more than one imputation

*keeping one out of 20 imputations
keep if _mi_m==8



*Recoding the income groups

recode _quintile (1/2=1 "first and second income quintile") (3/5=0 "third fourth fifth income quintile"), gen(income_quintile)
tab income_quintile


*******************************************
*1. (A) Exposure analysis - Variables DRM
*******************************************


*log using "drm_data_analysis_w4.log", replace
*log off



****************
**** Table 1
****************
	
	
	gen extreme_rainfall = 0
	*replace extreme_rainfall=. if v15_03a==98
	replace extreme_rainfall = 1 if (q15_04a == 1)
	lab def extreme_rainfall 0 "No Extr.Rainfall" 1 "Extreme Rainfall" 
    lab val extreme_rainfall extreme_rainfall
	
	gen severe_storms = 0
	*replace severe_storms=. if v15_03b==98
	replace severe_storms = 1 if (q15_04b == 1)
		lab def severe_storms 0 "No Storms" 1 "Severe Storms" 
    lab val severe_storms severe_storms
	
	gen floods = 0
	*replace floods=. if v15_03c==98
	replace floods = 1 if (q15_04c == 1)
	lab def floods 0 "No floods" 1 "Floods" 
    lab val floods floods
	
	gen hurricanes = 0
	*replace hurricanes=. if v15_03d==98
	replace hurricanes = 1 if (q15_04d == 1)
	lab def hurricanes 0 "No hurricanes" 1 "Hurricanes" 
    lab val hurricanes hurricanes
	
	gen heat_waves = 0
	*replace heat_waves=. if v15_03e==98
	replace heat_waves = 1 if (q15_04e == 1)
	lab def heat_waves 0 "No Heat" 1 "Heat Waves" 
    lab val heat_waves heat_waves
	
	gen drought = 0
	*replace drought=. if v15_03f==98
	replace drought = 1 if (q15_04f == 1)
		lab def drought 0 "No drought" 1 "Drought" 
    lab val drought drought
	
	gen wildfires = 0
	*replace wildfires=. if v15_03g==98
	replace wildfires = 1 if (q15_04g == 1)
	lab def wildfires 0 "No wildfires" 1 "Wildfires" 
    lab val wildfires wildfires
	
	/*gen volcanic_eruption = 0 - Not available
	*replace volcanic_eruption=. if v15_03h==98
	replace volcanic_eruption = 1 if (v15_03h == 1)
	*/
	
	gen earthquake = 0
	*replace earthquake=. if v15_03i==98
	replace earthquake = 1 if (q15_04h == 1)
		lab def earthquake 0 "No earthquake" 1 "Earthquake" 
    lab val earthquake earthquake
	
	gen landslides = 0
	*replace landslides=. if v15_03j==98
	replace landslides = 1 if (q15_04i == 1)
	lab def landslides 0 "No landslides" 1 "Landslides" 
    lab val landslides landslides
	
	gen high_sea_swells = 0
	*replace high_sea_swells=. if v15_03k==98
	replace high_sea_swells = 1 if (q15_04j == 1)
		lab def high_sea_swells 0 "No high_sea_swells" 1 "Sea Swells" 
    lab val high_sea_swells high_sea_swells
	
	gen tsunami = 0
	*replace tsunami=. if v15_03l==98
	replace tsunami = 1 if (q15_04k == 1)
	lab def tsunami 0 "No tsunami" 1 "Tsunami" 
    lab val tsunami tsunami

	cap drop other
	encode q15_04l, gen (other)
	tab q15_04l
	tab other, nol m

replace other=0 if inlist(other,1,2,3,4,5,6,20,21,22,23,24,25,26,27,28,29,30,31,32,33)
replace other=1 if inlist(other,7,8,9,10,11,12,13,14,15,16,17,18,19,34,35,36,37,38,39,40,41,42,43,44,45)
lab define others 1 "Other" 0 "no"
lab val other others
tab other

	*education of head of household
	recode q03_11 (1/8 = 1) (9/16 = 0) (99 = .), gen(education2)
	lab def education2 1 "No Educ./Primary" 0 "Secondary or more"
	lab val education2 education2
	replace education2=0 if q03_01!=1
	replace education2=1 if q03_13>=1 & q03_13<=8
	replace education2=0 if q03_13>=9 & q03_13<=16
	replace education2=. if q03_13==99
	tab education2
	
	

*log on	
**TOTAL by income
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_1_incometotal") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(13,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh] if   $varhet==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**URBAN
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_1_incomeurban") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(13,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh] if   $varhet==1 & q03_10==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0 & q03_10==1
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh] if q03_10==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**RURAL
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_1_incomerural") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet income_quintile
mat mat_t1=J(12,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh] if   $varhet==1 & q03_10==2
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0 & q03_10==2
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh] if q03_10==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

*****
	*by education
	
**TOTAL 
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_2_educationtotal") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="No educ./Primary (mean)"
putexcel C1="Secondary or more (mean))"
putexcel D1="Difference"


local i=1
global varhet education2
mat mat_t1=J(13,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh] if   $varhet==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**URBAN
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_2_educationurban") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet education2
mat mat_t1=J(12,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh] if   $varhet==1 & q03_10==1
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0 & q03_10==1
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh] if q03_10==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**RURAL
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_2_educationrural") modify		
putexcel A1="Type of Hazar"
putexcel A2="Heat Waves"
putexcel A3="Tropical cyclones/Hurricanes"
putexcel A4="Extreme Rainfall"
putexcel A5="Drought"
putexcel A6="Severe Storms"
putexcel A7="Floods"
putexcel A8="Earthquake"
putexcel A9="Wildfire"
putexcel A10="Tsunami"
putexcel A11="Landslides"
putexcel A12="Storm Surges"
putexcel A13="Other"

putexcel B1="Bottom 40 percent (mean)"
putexcel C1="Top 60 percent (mean)"
putexcel D1="Difference"


local i=1
global varhet education2
mat mat_t1=J(12,4,0) //Defining empty matrix

	foreach var of varlist heat_waves hurricanes extreme_rainfall drought severe_storms floods    earthquake wildfires tsunami landslides high_sea_swells  other {

		sum `var'  [aw=w_hh] if   $varhet==1 & q03_10==2
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0 & q03_10==2
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh] if q03_10==1, r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

	
*log off

*******************************************************************************
**Figure 4

tab q03_10 q15_01  [aw=w_hh] if haiti_regions==2, row
tabout q03_10 q15_01 [aw=w_hh] if haiti_regions==2  using tables_w4_drm.xls, c(row) f(1) append

**************************************************************
**** Figure 4d
**************************************************************


	
	gen emergency_plan = 0
	*replace emergency_plan=. if q15_13a==98
	replace emergency_plan = 1 if (q15_13a == 1) 
	tab emergency_plan
	
	gen committee = 0
	*replace committee=. if v15_12b==98
	replace committee = 1 if (q15_13b == 1 | q15_13b == 2)
	tab committee
	
	gen trained_community = 0
	*replace trained_community=. if v15_12c==98
	replace trained_community = 1 if (q15_13c == 1)
	tab trained_community

	gen evacuation_routes = 0
	*replace evacuation_routes=. if v15_12d==98
	replace evacuation_routes = 1 if (q15_13d == 1)
	tab evacuation_routes
	
	gen shelter = 0
	*replace shelter=. if v15_12e==98
	replace shelter = 1 if (q15_13e == 1)
	tab shelter
	
	
tab income_quintile emergency_plan 			[iw=w_hh], row nofreq
tab income_quintile committee 				[iw=w_hh], row nofreq
tab income_quintile trained_community 		[iw=w_hh], row nofreq
tab income_quintile evacuation_routes 		[iw=w_hh], row nofreq
tab income_quintile shelter 				[iw=w_hh], row nofreq

tabout income_quintile emergency_plan 		[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout income_quintile committee 			[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout income_quintile trained_community 	[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout income_quintile evacuation_routes 	[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append
tabout income_quintile shelter 				[iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append 
	
	
**************************************************************
**** Chechking significance for first paragraph third section
**************************************************************
*log on

*by education
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate education2 [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.education2 [aw=w_hh], vce(robust)
	
	
	}
	
*by income
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {

	tabulate income_quintile [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist emergency_plan committee trained_community evacuation_routes shelter {
	
	reg `var' i.income_quintile [aw=w_hh], vce(robust)
	
	
	}

*log off

**************************************************************
**** Table 2
**************************************************************
**RURAL
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_2_paper") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Evacuation Routes"
putexcel A3="Shelter"
putexcel A4="Trained Community"
putexcel A5="Committee"
putexcel A6="Emergency Plan"


putexcel B1="Urban (mean)"
putexcel C1="Rural (mean)"
putexcel D1="Difference"

cap drop area
recode q03_10 (1=1 "Urban") (2=0 "Rural"), gen(area)

local i=1
global varhet area
mat mat_t1=J(5,4,0) //Defining empty matrix

	foreach var of varlist evacuation_routes shelter trained_community committee emergency_plan    {

		sum `var'  [aw=w_hh] if   $varhet==1 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0  
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**OVERALL
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_2_female") modify		
putexcel B1="Overall"
local i=1
mat mat_ov=J(5,1,0) //Defining empty matrix

	foreach var of varlist evacuation_routes shelter trained_community committee emergency_plan    {

		sum `var'  [aw=w_hh] 
		mat mat_ov[ `i',1]=r(mean)
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_ov), nformat(number_sep_d2)	

**BY SEX
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_2_female") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Evacuation Routes"
putexcel A3="Shelter"
putexcel A4="Trained Community"
putexcel A5="Committee"
putexcel A6="Emergency Plan"


putexcel C1="Male (mean)"
putexcel D1="Female (mean)"
putexcel E1="Difference"

cap drop female_a
gen female_a=.
replace female_a=0 if (q03_06==2 & q03_01==1) | q03_14==2
replace female_a=1 if (q03_06==1 & q03_01==1) | q03_14==1
tab female_a 
label def female_a 0 "Female" 1 "Male"
label val female_a female_a

local i=1
global varhet female_a
mat mat_t1=J(5,4,0) //Defining empty matrix

	foreach var of varlist evacuation_routes shelter trained_community committee emergency_plan    {

		sum `var'  [aw=w_hh] if   $varhet==1 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0  
		mat mat_t1[ `i',2]=r(mean)
		mat mat_t1[ `i' ,3]=mat_t1[ `i',2]-mat_t1[ `i',1]
		reg `var'  $varhet [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',4]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel C2=matrix(mat_t1), nformat(number_sep_d2)



**************************************************************
**** Table 3 (paper)
**************************************************************


	**********
	*** Do you have supplies or other things in your home that could be used to help your household in a disaster or emergency?
	**********	
		
	tab q15_06, m
	tab q15_06, nol
	
	gen have_supplies = 0
	*replace have_supplies=. if v15_05==98
	replace have_supplies = 1	if (q15_06 == 1)
	tab have_supplies
	
	
	**********
	*** Have you and your family members ever talked about or planned what you would do in the event of a disaster or emergency?
	**********	
		
	tab q15_08, m
	tab q15_08, nol
	
	gen family_talked = 0
	*replace family_talked=. if v15_07==98	
	replace family_talked = 1	if (q15_08 == 1)
	tab family_talked

	****************
	*** - Compared to just before the pandemic, do you feel that your household is better prepared, equally prepared, or less prepared to deal with a disaster or emergency? 
	****************

	
	tab q15_10, m
	tab q15_10, nol
	
	*Category "zero" will be more/equally prepared or don't know
	gen less_prepared = 0
	replace less_prepared = 1 if (q15_10 ==3)
	tab less_prepared



	
	****************
	*** - Do you feel that your household is very prepared, somewhat prepared, or not prepared to deal with a disaster or emergency at this time?
	****************
	
	tab q15_05, m
	tab q15_05, nol
		
	*zero will be very/somewhat prepared or don't know
	gen not_prepared = 0
	replace not_prepared = 1 if (q15_05 == 3)
	tab not_prepared
	
/*log on	

	foreach var of varlist have_supplies family_talked not_prepared less_prepared  {

	tabulate income_quintile [aw=w_hh], summarize(`var')
	
	}
	
	foreach var of varlist have_supplies family_talked not_prepared less_prepared  {
	
	reg `var' i.income_quintile [aw=w_hh], vce(robust)
	
	
	}
		
log off
log close */

*By QUintile.
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_3_upper") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Household with supplies"
putexcel A3="The family talked about what you would do in a disaster"
putexcel A4=" Currently not prepared to respond to a disaster"
putexcel A5="Less prepared compared to pre-pandemic"
putexcel B1="Overrall"
putexcel C1="Bottom 40 percent (mean)"
putexcel D1="Top 60 percent (mean)"
putexcel E1="Difference"

local i=1
global income income_quintile
mat mat_t1=J(4,5,0) //Defining empty matrix

	foreach var of varlist have_supplies family_talked not_prepared less_prepared   {

	    sum `var'  [aw=w_hh] 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if   $income==1 
		mat mat_t1[ `i',2]=r(mean)
		sum `var'  [aw=w_hh] if  $income==0  
		mat mat_t1[ `i',3]=r(mean)
		mat mat_t1[ `i' ,4]=mat_t1[ `i',3]-mat_t1[ `i',2]
		reg `var'  $income [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',5]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)


*By Area
putexcel set "$out/Tables_DRM_w4.xlsx", sheet("table_4") modify		
*putexcel A1="Type of Hazar"
putexcel A2="Household with supplies"
putexcel A3="The family talked about what you would do in a disaster"
putexcel A4=" Currently not prepared to respond to a disaster"
putexcel A5="Less prepared compared to pre-pandemic"
putexcel B1="Overrall"
putexcel C1="Urban (mean)"
putexcel D1="Rural (mean)"
putexcel E1="Difference"

cap drop area
recode q03_10 (1=1 "Urban") (2=0 "Rural"), gen(area)

local i=1
global varhet area
mat mat_t1=J(4,5,0) //Defining empty matrix

	foreach var of varlist have_supplies family_talked not_prepared less_prepared   {

	    sum `var'  [aw=w_hh] 
		mat mat_t1[ `i',1]=r(mean)
		sum `var'  [aw=w_hh] if   $varhet==1 
		mat mat_t1[ `i',2]=r(mean)
		sum `var'  [aw=w_hh] if  $varhet==0  
		mat mat_t1[ `i',3]=r(mean)
		mat mat_t1[ `i' ,4]=mat_t1[ `i',3]-mat_t1[ `i',2]
		reg `var'  $varhet [aw=w_hh], r 
		matrix pval = r(table)
		mat mat_t1[`i',5]=pval[4,1]	
	local i=`i'+1
	
	}
putexcel B2=matrix(mat_t1), nformat(number_sep_d2)

**************************************************************
**** Figure 9
**************************************************************
*Creating Variables 
*3.2 In school after the pandemic 
gen pos_school=1 if q08_03==1 
replace pos_school=0 if q08_03==2 | q08_03==98

*attending childcare last week
gen childcare=0 if q08_19==2
replace childcare=1 if q08_19==1

* education in-person
gen educpres = 0 if q08_02 != .
replace educpres = 1 if q08_05 == 1 
replace educpres = . if q08_06 == 1 & q08_10 == 1
lab def educpres 0 "Not in person educ" 1 "In person educ"
lab val educpres educpres

*virtual
gen virtual=0 if q08_07==2 | q08_07==98
replace virtual=1 if q08_07==1

***Variables to be matched with w1
*EXCLqDE corona treatment (not available in wave 1)
gen medneed = (q02_03_a == 1 | q02_03_b == 1 | q02_03_c == 1 | q02_03_d == 1 | ///
 q02_03_e == 1 | q02_03_f == 1 | q02_03_g == 1 | q02_03_h == 1 | q02_03_i == 1 | /// 
 q02_03_j == 1 | q02_03_k == 1 | q02_03_l == 1 | q02_03_z == 1) 
 tab q03_10 medneed [iw=w_hh], row nofreq

*Models for each hazard

probit pos_school i.heat_waves i.hurricanes i.extreme_rainfall i.drought i.severe_storms i.floods    i.earthquake i.wildfires i.tsunami i.landslides i.high_sea_swells  [iw=w_hh] if q03_10==1, vce(robust)
estimates store pos_schoolur
estimates restore pos_schoolur
margins, dydx(*) vce(unconditional) post
estimates store marg_poschoolur

probit childcare i.heat_waves i.hurricanes i.extreme_rainfall i.drought i.severe_storms i.floods    i.earthquake i.wildfires i.tsunami i.landslides i.high_sea_swells  [iw=w_hh] if q03_10==1, vce(robust)
estimates store childcareur
estimates restore childcareur
margins, dydx(*) vce(unconditional) post
estimates store marg_childcareur

probit pos_school i.heat_waves i.hurricanes i.extreme_rainfall i.drought i.severe_storms i.floods    i.earthquake i.wildfires i.tsunami i.landslides i.high_sea_swells  [iw=w_hh] if q03_10==2, vce(robust)
estimates store pos_schoolrur
estimates restore pos_schoolrur
margins, dydx(*) vce(unconditional) post
estimates store marg_poschoolrur

probit childcare i.heat_waves i.hurricanes i.extreme_rainfall i.drought i.severe_storms i.floods    i.earthquake i.wildfires i.tsunami i.landslides i.high_sea_swells  [iw=w_hh] if q03_10==2, vce(robust)
estimates store childcarerur
estimates restore childcarerur
margins, dydx(*) vce(unconditional) post
estimates store marg_childcarerur

probit medneed i.heat_waves i.hurricanes i.extreme_rainfall i.drought i.severe_storms i.floods    i.earthquake i.wildfires i.tsunami i.landslides i.high_sea_swells [iw=w_hh] if q03_10==1, vce(robust)
estimates store medneedur
estimates restore medneedur
margins, dydx(*) vce(unconditional) post
estimates store marg_medneedur

probit medneed i.heat_waves i.hurricanes i.extreme_rainfall i.drought i.severe_storms i.floods    i.earthquake i.wildfires i.tsunami i.landslides i.high_sea_swells [iw=w_hh] if q03_10==1, vce(robust)
estimates store medneedrur
estimates restore medneedrur
margins, dydx(*) vce(unconditional) post
estimates store marg_medneedrur


coefplot marg_medneedur, bylabel("Medical Services" "Urban") ///
		|| marg_poschoolur, bylabel("School Attendance" "Urban") ///
		|| marg_childcareur, bylabel("Childcare Attendance" "Urban") ///
		|| marg_medneedrur, bylabel("Medical Services" "Rural") ///
		|| marg_poschoolrur, bylabel("School Attendance" "Rural") ///
		|| marg_childcarerur, bylabel("Childcare Attendance"  "Rural") ///
		||,drop(_cons) xline(0, lcolor(red) lpattern(dash)) scheme(sj)
		
graph export "$out/graph3ur_w4.png", replace



**************************************************************
****Figure 7 
**************************************************************


tab haiti_regions

tab income_quintile haiti_regions [iw=w_hh], row nofreq
tabout income_quintile haiti_regions [iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append

tab income_quintile q15_01 if haiti_regions==2 [iw=w_hh], row nofreq
tabout income_quintile q15_01 if haiti_regions==2 [iw=w_hh] using tables_w4_drm.xls, c(row) f(1) append

reg q15_01 i.income_quintile [aw=w_hh] if haiti_regions==2, vce(robust)

**************************************************************
*Summary Statistics: Appendix
**************************************************************
* Sex household head

tab q03_01
gen household_head_fem=.
replace household_head_fem=1 if (q03_06==2 & q03_01==1) | q03_14==2
replace household_head_fem=0 if (q03_06==1 & q03_01==1) | q03_14==1
tab household_head_fem 
label def household_head_fem 1 "Female" 0 "Male"
label val household_head_fem household_head_fem

*household head age
gen edad_proxy = 2023 - q03_04a + 1 	
label var edad_proxy "Edad aprox. en 2023"
tab edad_proxy
replace edad_proxy=. if edad_proxy==-7975
tab edad_proxy
replace edad_proxy=q03_05 if edad_proxy==.
replace edad_proxy=q03_05 if (edad_proxy!=. & q03_05!=.)
tab edad_proxy
*br edad_proxy q03_05
replace edad_proxy=. if edad_proxy==99
recode edad_proxy (18/29=1 "18 to 29") (30/49=2 "30 to 49") (50/124=3 "50+"), gen(age_head)
tab age_head

*children 0-17 at home
tab q07_16, m
recode q07_16 (0=0 "no children") (1/2=1 "1-2 children") (3/8=3 "3+ children"), gen(children)
tab children, m

*education of head of household
recode q03_11 (1/8 = 1) (9/15 = 2) (16 = 3) (99 = .), gen(education)
lab def education 1 "No Educ./Primary" 2 "Secondary" 3 "Tertiary or more"
lab val education education
replace education=0 if q03_01!=1
replace education=1 if q03_13>=1 & q03_13<=8
replace education=2 if q03_13>=9 & q03_13<=15
replace education=3 if q03_13==16
replace education=. if q03_13==99
tab education

*location
tab haiti_regions
recode haiti_regions (1=1 "Ouest") (2=2 "Southern") (3=3 "Northern") (4=4 "Central"), gen (region)

tab household_head_fem [aw=w_hh] //sex
tabout household_head_fem [aw=w_hh]  using tablesw4_ss.xls, c(col) replace

tab age_head [aw=w_hh]  //age
tabout age_head [aw=w_hh]  using tablesw4_ss.xls, c(col) append

tab education [aw=w_hh] //education2
tabout education [aw=w_hh]  using tablesw4_ss.xls, c(col) append

tab _quintile [aw=w_hh] //income
tabout _quintile [aw=w_hh]  using tablesw4_ss.xls, c(col) append

tab area [aw=w_hh] //area
tabout area [aw=w_hh]  using tablesw4_ss.xls, c(col) append

tab haiti_regions [aw=w_hh] //region
tabout haiti_regions [aw=w_hh]  using tablesw4_ss.xls, c(col) append

